@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-close-confirmation-dialog.c,v 1.20 2006/08/24 15:08:34 paolo Exp $
+ * $Id: gedit-close-confirmation-dialog.c 5345 2006-12-07 23:33:28Z paolo $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -469,7 +469,7 @@ get_text_secondary_label (GeditDocument *doc)
 		hours = seconds / 3600;
 
 		secondary_msg = g_strdup_printf (
-					ngettext ("If you don't save, changes from the last hour "
+					ngettext ("If you don't save, changes from the last %d hour "
 					    	  "will be permanently lost.",
 						  "If you don't save, changes from the last %d hours "
 					    	  "will be permanently lost.",
