@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c,v 1.14 2006/08/24 15:08:33 paolo Exp $
+ * $Id: gedit-commands-file.c 5462 2007-01-27 17:10:16Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,15 +134,15 @@ load_file_list (GeditWindow         *window,
 	GList         *win_docs;
 	GSList        *uris_to_load = NULL;
 	const GSList  *l;
-	
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	g_return_val_if_fail ((uris != NULL) && (uris->data != NULL), 0);
 
 	win_docs = gedit_window_get_documents (window);
 
-	/* Remove the uris corresponding to documents already open in "window".
-	   Add remove duplicates from "uris" list */
+	/* Remove the uris corresponding to documents already open
+	 * in "window" and remove duplicates from "uris" list */
 	l = uris;
 	while (uris != NULL)
 	{
@@ -155,8 +155,20 @@ load_file_list (GeditWindow         *window,
 				{
 					gedit_window_set_active_tab (window, tab);
 					jump_to = FALSE;
+
+					if (line_pos > 0)
+					{
+						GeditDocument *doc;
+						GeditView *view;
+
+						doc = gedit_tab_get_document (tab);
+						view = gedit_tab_get_view (tab);
+
+						gedit_document_goto_line (doc, line_pos);
+						gedit_view_scroll_to_cursor (view);
+					}
 				}
-				
+
 				++loaded_files;
 			}
 			else
@@ -165,7 +177,7 @@ load_file_list (GeditWindow         *window,
 								uris->data);
 			}
 		}
-				
+
 		uris = g_slist_next (uris);
 	}
 
@@ -173,7 +185,7 @@ load_file_list (GeditWindow         *window,
 
 	if (uris_to_load == NULL)
 		return loaded_files;
-		
+	
 	uris_to_load = g_slist_reverse (uris_to_load);
 	l = uris_to_load;
 
@@ -1081,30 +1093,14 @@ _gedit_cmd_file_save_all (GtkAction   *action,
 
 /* File revert */
 static void
-revert_dialog_response_cb (GtkDialog     *dialog,
-			   gint           response_id,
-			   GeditWindow   *window)
+do_revert (GeditWindow *window,
+	   GeditTab    *tab)
 {
-	GeditTab *tab;
 	GeditDocument *doc;
 	gchar *docname;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	/* FIXME: we are relying on the fact that the dialog is
-	   modal so the active tab can't be changed...
-	   not very nice - Paolo (Oct 11, 2005) */
-	tab = gedit_window_get_active_tab (window);
-	if (tab == NULL)
-		return;
-
-	if (response_id != GTK_RESPONSE_OK)
-	{
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-
-		return;
-	}
-
 	doc = gedit_tab_get_document (tab);
 	docname = gedit_document_get_short_name_for_display (doc);
 
@@ -1114,11 +1110,34 @@ revert_dialog_response_cb (GtkDialog     *dialog,
 				       docname);
 
 	g_free (docname);
-	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	_gedit_tab_revert (tab);
 }
 
+static void
+revert_dialog_response_cb (GtkDialog   *dialog,
+			   gint         response_id,
+			   GeditWindow *window)
+{
+	GeditTab *tab;
+
+	gedit_debug (DEBUG_COMMANDS);
+
+	/* FIXME: we are relying on the fact that the dialog is
+	   modal so the active tab can't be changed...
+	   not very nice - Paolo (Oct 11, 2005) */
+	tab = gedit_window_get_active_tab (window);
+	if (tab == NULL)
+		return;
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	if (response_id == GTK_RESPONSE_OK)
+	{
+		do_revert (window, tab);
+	}
+}
+
 static GtkWidget *
 revert_dialog (GeditWindow   *window,
 	       GeditDocument *doc)
@@ -1202,7 +1221,7 @@ revert_dialog (GeditWindow   *window,
 		hours = seconds / 3600;
 
 		secondary_msg = g_strdup_printf (
-					ngettext ("Changes made to the document in the last hour "
+					ngettext ("Changes made to the document in the last %d hour "
 					    	  "will be permanently lost.",
 						  "Changes made to the document in the last %d hours "
 					    	  "will be permanently lost.",
@@ -1242,13 +1261,26 @@ void
 _gedit_cmd_file_revert (GtkAction   *action,
 		       GeditWindow *window)
 {
+	GeditTab       *tab;
 	GeditDocument  *doc;
 	GtkWidget      *dialog;
 	GtkWindowGroup *wg;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	doc = gedit_window_get_active_document (window);
+	tab = gedit_window_get_active_tab (window);
+	g_return_if_fail (tab != NULL);
+
+	/* If we are already displaying a notification
+	 * reverting will drop local modifications, do
+	 * not bug the user further */
+	if (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION)
+	{
+		do_revert (window, tab);
+		return;
+	}
+
+	doc = gedit_tab_get_document (tab);
 	g_return_if_fail (doc != NULL);
 	g_return_if_fail (!gedit_document_is_untitled (doc));
 
