@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document-loader.c,v 1.9 2006/08/25 09:30:34 pborelli Exp $
+ * $Id: gedit-document-loader.c 5474 2007-02-06 13:36:18Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -257,6 +257,11 @@ insert_text_in_document (GeditDocumentLoader *loader,
 	gtk_source_buffer_begin_not_undoable_action (
 				GTK_SOURCE_BUFFER (loader->priv->document));
 
+	/* If the last char is a newline, don't add it to the buffer
+	(otherwise GtkTextView shows it as an empty line). See bug #324942. */
+	if (text[len-1] == '\n')
+		len--;
+
 	/* Insert text in the buffer */
 	gtk_text_buffer_set_text (GTK_TEXT_BUFFER (loader->priv->document), 
 				  text, 
@@ -515,7 +520,28 @@ load_local_file_real (GeditDocumentLoader *loader)
 
 		goto done;
 	}
-	
+
+	/* not a regular file */
+	if (!S_ISREG (statbuf.st_mode))
+	{
+		if (S_ISDIR (statbuf.st_mode))
+		{
+			g_set_error (&loader->priv->error,
+				     GEDIT_DOCUMENT_ERROR,
+				     GNOME_VFS_ERROR_IS_DIRECTORY,
+				     gnome_vfs_result_to_string (GNOME_VFS_ERROR_IS_DIRECTORY));
+		}
+		else
+		{
+			g_set_error (&loader->priv->error,
+				     GEDIT_DOCUMENT_ERROR,
+				     GEDIT_DOCUMENT_ERROR_NOT_REGULAR_FILE,
+				     "Not a regular file");
+		}
+
+		goto done;
+	}
+
 	loader->priv->info = gnome_vfs_file_info_new ();
 	stat_to_file_info (loader->priv->info, &statbuf);
 	GNOME_VFS_FILE_INFO_SET_LOCAL (loader->priv->info, TRUE);
@@ -590,6 +616,7 @@ load_local_file_real (GeditDocumentLoader *loader)
 				   strerror (errno));
 	}
 
+ done:
 	ret = close (loader->priv->fd);
 
 	if (ret != 0)
@@ -599,7 +626,6 @@ load_local_file_real (GeditDocumentLoader *loader)
 
 	loader->priv->fd = -1;
 
- done:
 	load_completed_or_failed (loader);
 	
 	return FALSE;
@@ -818,8 +844,8 @@ remote_get_info_cb (GnomeVFSAsyncHandle *handle,
 	{
 		g_set_error (&loader->priv->error,
 			     GEDIT_DOCUMENT_ERROR,
-			     GNOME_VFS_ERROR_GENERIC, // FIXME
-			     gnome_vfs_result_to_string (GNOME_VFS_ERROR_GENERIC));
+			     GEDIT_DOCUMENT_ERROR_NOT_REGULAR_FILE,
+			     "Not a regular file");
 
 		remote_load_completed_or_failed (loader);
 
